@@ -3,8 +3,6 @@ use std::path::{Path, PathBuf};
 use anyhow::{anyhow, bail, Context, Result};
 use clap::Parser;
 use directories_next::BaseDirs;
-use ignore::gitignore::Gitignore;
-use ignore::Match;
 
 use skyspell_core::repository::RepositoryHandler;
 use skyspell_core::Checker;
@@ -13,7 +11,7 @@ use skyspell_core::OperatingSystemIO;
 use skyspell_core::ProjectPath;
 use skyspell_core::TokenProcessor;
 use skyspell_core::{get_default_db_path, SQLRepository};
-use skyspell_core::{Dictionary, IgnoreStore, Repository};
+use skyspell_core::{Dictionary, IgnoreFile, IgnoreStore, Repository};
 use skyspell_kak::{new_kakoune_io, KakouneChecker, KakouneIO};
 
 // Warning: most of the things written to stdout while this code is
@@ -112,7 +110,7 @@ pub fn main() -> Result<()> {
     let project_path = PathBuf::from(project_as_str);
     let project = ProjectPath::new(&project_path)?;
     let checker = KakouneChecker::new(project, dictionary, repository, kakoune_io)?;
-    let mut cli = KakCli::new(checker);
+    let mut cli = KakCli::new(checker)?;
 
     let outcome = match opts.action {
         Action::AddExtension => cli.add_extension(),
@@ -137,11 +135,24 @@ pub fn main() -> Result<()> {
 
 struct KakCli<D: Dictionary, R: Repository, S: OperatingSystemIO> {
     checker: KakouneChecker<D, R, S>,
+    home_dir: String,
+    ignore_file: IgnoreFile,
 }
 
 impl<D: Dictionary, R: Repository, S: OperatingSystemIO> KakCli<D, R, S> {
-    fn new(checker: KakouneChecker<D, R, S>) -> Self {
-        Self { checker }
+    fn new(checker: KakouneChecker<D, R, S>) -> Result<Self> {
+        let base_dirs = BaseDirs::new().ok_or_else(|| anyhow!("Could not get home directory"))?;
+        let home_dir = base_dirs
+            .home_dir()
+            .to_str()
+            .ok_or_else(|| anyhow!("Non-UTF8 chars in home dir"))?;
+        let project = checker.project();
+        let ignore_file = IgnoreFile::new(project);
+        Ok(Self {
+            home_dir: home_dir.to_string(),
+            checker,
+            ignore_file,
+        })
     }
 
     fn kakoune_io(&self) -> &KakouneIO<S> {
@@ -168,7 +179,7 @@ impl<D: Dictionary, R: Repository, S: OperatingSystemIO> KakCli<D, R, S> {
     fn add_extension(&mut self) -> Result<()> {
         let LineSelection { path, word, .. } = &self.parse_line_selection()?;
         let (_, ext) = path
-            .rsplit_once(".")
+            .rsplit_once('.')
             .ok_or_else(|| anyhow!("File has no extension"))?;
         self.repository_handler().ignore_for_extension(word, ext)?;
         self.recheck();
@@ -231,22 +242,12 @@ impl<D: Dictionary, R: Repository, S: OperatingSystemIO> KakCli<D, R, S> {
     }
 
     fn check(&mut self, opts: &CheckOpts) -> Result<()> {
-        // Note:
-        // kak_buflist may:
-        //  * contain special buffers, like *debug*
-        //  * use ~ for home dir
-        let base_dirs = BaseDirs::new().ok_or_else(|| anyhow!("Could not get home directory"))?;
-        let home_dir = base_dirs
-            .home_dir()
-            .to_str()
-            .ok_or_else(|| anyhow!("Non-UTF8 chars in home dir"))?;
-
-        let ignore_path = ".skyspell-ignore";
-        let (skyspell_ignore, _error) = Gitignore::new(ignore_path);
-        // Note: _error will be Some(Err) if there's a invalid glob in .skyspell-ignore
-        // for instance, but we don't care about that.
-
         for bufname in &opts.buflist {
+            // Note:
+            // kak_buflist may:
+            //  * be escaped
+            //  * contain special buffers, like *debug*
+            //  * use ~ for home dir
             let bufname = self.unescape(bufname);
 
             if bufname.starts_with('*') && bufname.ends_with('*') {
@@ -260,7 +261,7 @@ impl<D: Dictionary, R: Repository, S: OperatingSystemIO> KakCli<D, R, S> {
                 bufname
             ));
 
-            let full_path = bufname.replace("~", home_dir);
+            let full_path = bufname.replace('~', &self.home_dir);
             let source_path = Path::new(&full_path);
 
             if !source_path.exists() {
@@ -275,9 +276,8 @@ impl<D: Dictionary, R: Repository, S: OperatingSystemIO> KakCli<D, R, S> {
                 continue;
             }
 
-            match skyspell_ignore.matched(&relative_path, /*is-dir*/ false) {
-                Match::Ignore(_) => continue,
-                Match::None | Match::Whitelist(_) => (),
+            if self.ignore_file.is_ignored(&relative_path) {
+                continue;
             }
 
             let token_processor = TokenProcessor::new(source_path);
